@@ -1,5 +1,5 @@
 
-/* Copyright (C) 2011-2017  Lucio Carreras
+/* Copyright (C) 2011-2019  Lucio Carreras
  *
  * This file is part of sayonara player
  *
@@ -23,37 +23,28 @@
 #include <QThread>
 #include <QSharedMemory>
 #include <QMainWindow>
-
-enum InstanceMessage {
-	InstanceMessageNone,
-	InstanceMessageWithoutFiles,
-	InstanceMessageWithFiles
-};
+#include "Utils/Pimpl.h"
 
 
 class InstanceThread : public QThread
 {
 	Q_OBJECT
+	PIMPL(InstanceThread)
 
 signals:
 	void sig_player_raise();
-	void sig_create_playlist(const QStringList& playlist, const QString& name, bool temporary);
+	void sig_create_playlist();
 
 public:
-		InstanceThread(InstanceMessage* instance_message, QObject* parent=nullptr);
-		~InstanceThread();
+	InstanceThread(QObject* parent=nullptr);
+	~InstanceThread();
 
-		void stop();
+	void stop();
+	QStringList paths() const;
 
 private:
-		bool				_may_run;
-		InstanceMessage*	_instance_message=nullptr;
-		QSharedMemory		_memory;
-
-
-private:
-		void run() override;
-		void parse_memory();
+	void run() override;
+	void parse_memory();
 };
 
 #endif // INSTANCETHREAD_H
