@@ -1,6 +1,6 @@
 /* DBusHandler.h */
 
-/* Copyright (C) 2011-2017  Lucio Carreras
+/* Copyright (C) 2011-2019  Lucio Carreras
  *
  * This file is part of sayonara player
  *
@@ -21,34 +21,28 @@
 #ifndef DBUSHANDLER_H
 #define DBUSHANDLER_H
 
+#include "Utils/Pimpl.h"
 #include <QObject>
-#include <QList>
-#include <QMainWindow>
 
-class DBusMediaKeysInterfaceMate;
-class DBusMediaKeysInterfaceGnome;
-class DBusNotifications;
-
-
-namespace DBusMPRIS 
+class QMainWindow;
+namespace DBusMPRIS
 {
 	class MediaPlayer2;
 }
 
 class DBusHandler :
-		private QObject
+		public QObject
 {
+	Q_OBJECT
+	PIMPL(DBusHandler)
 
 public:
-	explicit DBusHandler(QMainWindow* player, QObject* parent=nullptr);
-	~DBusHandler();
+	explicit DBusHandler(QMainWindow* main_window, QObject* parent=nullptr);
+	virtual ~DBusHandler();
 
-
-private:
-	DBusMPRIS::MediaPlayer2*		_dbus_mpris=nullptr;
-	DBusMediaKeysInterfaceMate*		_dbus_mate=nullptr;
-	DBusMediaKeysInterfaceGnome*	_dbus_gnome=nullptr;
-	DBusNotifications*				_dbus_notifications=nullptr;
+private slots:
+	void service_registered(const QString& service_name);
+	void service_unregistered(const QString& service_name);
 };
 
 #endif // DBUSHANDLER_H
